/*!
 * @nuxt/typescript-edge v2.5.0-25853767.83db9595 (c) 2016-2019

 * - All the amazing contributors
 * Released under the MIT License.
 * Website: https://nuxtjs.org
*/
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

const chalk = _interopDefault(require('chalk'));
const consola = _interopDefault(require('consola'));
const env = _interopDefault(require('std-env'));
const enquirer = require('enquirer');
const fsExtra = require('fs-extra');
const tsNode = require('ts-node');

async function generateTsConfig(tsConfigPath) {
  const configToExtend = '@nuxt/typescript-edge';
  await fsExtra.writeJSON(tsConfigPath, {
    extends: configToExtend,
    compilerOptions: {
      baseUrl: '.',
      types: [
        '@types/node',
        '@nuxt/vue-app-edge'
      ]
    }
  }, { spaces: 2 });
  consola.info(`Extending ${chalk.bold.blue(`node_modules/${configToExtend}/tsconfig.json`)}`);
  consola.success(`Generated successfully at ${chalk.bold.green(tsConfigPath)}`);
}

let _setup = false;

async function setup(tsConfigPath) {
  if (_setup) {
    return
  }
  _setup = true;

  if (!fsExtra.existsSync(tsConfigPath)) {
    const { confirmGeneration } = await enquirer.prompt({
      type: 'confirm',
      name: 'confirmGeneration',
      message: `${chalk.bold.blue(tsConfigPath)} is missing, generate it ?`,
      initial: true,
      skip: env.minimal
    });

    if (confirmGeneration) {
      await generateTsConfig(tsConfigPath);
    }
  }
  // https://github.com/TypeStrong/ts-node
  tsNode.register({
    project: tsConfigPath,
    compilerOptions: {
      module: 'commonjs'
    },
    transpileOnly: process.argv[2] === 'start'
  });
}

exports.setup = setup;
